# pybirdsreynolds
pybirdsreynolds is a simulation of bird flocking behavior using Reynolds rules

<img width="1418" height="549" alt="Image" src="https://github.com/user-attachments/assets/ac49adbf-fd2f-4d3a-b205-97d67ab893c8" />

# Installation/Upgrade 

## Prerequisites

- Install Python 3 for your system
- Install pipx for your system

## Installation 

``pipx install pybirdsreynolds``

## Upgrade 

``pipx upgrade pybirdsreynolds``

# Use

```pybirdsreynolds```

- If you obtain error about tk, install python3-tk
``` 
sudo apt install python3-tk #for ubuntu
sudo pacman -S tk #for arch
```

# Documentation and options

```pybirdsreynolds --help```
